@@ -30,9 +30,10 @@
 # define DIFF_PROGRAM "diff"
 #endif
 
-/* One may also, optionnaly, define a default PAGER_PROGRAM.  This might
-   be done from the Makefile.  If PAGER_PROGRAM is undefined and the
-   PAGER environment variable is not set, none will be used.  */
+/* One may also, optionnaly, define a default PAGER_PROGRAM.  This
+   might be done using the --with-default-pager=PAGER configure
+   switch.  If PAGER_PROGRAM is undefined and the PAGER environment
+   variable is not set, none will be used.  */
 
 /* Define the separator lines when output is inhibited.  */
 #define SEPARATOR_LINE \
@@ -53,10 +54,6 @@
 # endif
 #endif
 
-#ifndef strstr
-char *strstr ();
-#endif
-
 #if HAVE_TPUTS
 # if HAVE_TERMCAP_H
 #  include <termcap.h>
@@ -91,8 +88,8 @@ char *strstr ();
 #include <sys/wait.h>
 
 char *getenv ();
-FILE *readpipe PARAMS ((const char *, ...));
-FILE *writepipe PARAMS ((const char *, ...));
+FILE *readpipe (const char *, ...);
+FILE *writepipe (const char *, ...);
 
 /* Declarations.  */
 
@@ -1060,7 +1057,6 @@ static void
 launch_output_program (void)
 {
   char *program;		/* name of the pager */
-  char *basename;		/* basename of the pager */
 
   /* Check if a output program should be called, and which one.  Avoid
      all paging if only statistics are needed.  */
@@ -1097,12 +1093,25 @@ launch_output_program (void)
   if (program && *program)
     {
       int is_less;
+      char *realprogram;	/* symlink-resolved path of the pager */
+      char *basename;		/* basename of the pager */
 
-      if (basename = strrchr (program, '/'), basename)
+      if (program[0] == '/') {
+        realprogram = realpath(program, NULL);
+        if (realprogram == NULL)
+          realprogram = program;
+      }
+      else {
+        realprogram = program;
+      }
+      basename = strrchr (realprogram, '/');
+      if (basename)
 	basename++;
       else
 	basename = program;
       is_less = strstr (basename, "less") != NULL;
+      if (realprogram != program)
+        free (realprogram);
 
       if (is_less && no_init_term)
 	output_file = writepipe (program, "-X", NULL);
